@@ -73,10 +73,16 @@ def get_tags_from_json(info_json):
 def print_if_true(in_string, do_print):
     if do_print:
         print(in_string)
-def download_image(post_id, output_folder=".", name_pattern=__default_name_pattern__, add_tags=True, messages=True, user_agent=__default_user_agent__):
+def download_image(post_id, output_folder=".", name_pattern=__default_name_pattern__, add_tags=True, messages=True, custom_json=None, user_agent=__default_user_agent__):
+    print_if_true("[{}] Downloading e621 post...".format(post_id), messages)
     # Get information from e621 API
-    print_if_true("[{}] Getting info for e621 post...".format(post_id), messages)
-    image_info = get_info_json(post_id, user_agent=user_agent)
+    if custom_json != None:
+        image_info = custom_json
+    else:
+        print_if_true("    Getting info for e621 post...".format(post_id), messages)
+        image_info = get_info_json(post_id, user_agent=user_agent)
+    
+    # Check to make sure it's valid
     if image_info == None:
         print_if_true("    ERROR: No info returned.", messages)
         return None
@@ -126,8 +132,8 @@ def parse_args(args):
     
     parser.add_argument("-i", "--post_id", dest="post_id", help="the ID of the e621 post", type=int, required=True, metavar="ID")
     parser.add_argument("-f", "--dl_folder", dest="dl_folder", help="the folder to download to", type=dir_path, default=".", metavar="FOLDER")
-    parser.add_argument("-p", "--name_pattern", dest="name_pattern", help="the file name, Replacements: {m}=md5, {i}=post_id ", type=str, default=__default_name_pattern__, metavar="NAME")
-    parser.add_argument("-n", "--no_tags", dest="add_tags", help="don't save tags or metadata", action='store_false')
+    parser.add_argument("-n", "--name_pattern", dest="name_pattern", help="the file name, Replacements: {m}=md5, {i}=post_id ", type=str, default=__default_name_pattern__, metavar="NAME")
+    parser.add_argument("-t", "--no_tags", dest="add_tags", help="don't save tags or metadata", action='store_false')
     parser.add_argument("-u", "--user_agent", dest="user_agent", help="manual override of the user agent string", type=str, default=__default_user_agent__, metavar="USERAGENT")
     
     return parser.parse_args(args)
@@ -135,7 +141,7 @@ def parse_args(args):
 def main(args):
     args = parse_args(args)
     
-    download_image(post_id=args.post_id, output_folder=args.dl_folder, name_pattern=args.name_pattern, add_tags=args.add_tags, messages=True, user_agent=args.user_agent)
+    download_image(post_id=args.post_id, output_folder=args.dl_folder, name_pattern=args.name_pattern, add_tags=args.add_tags, user_agent=args.user_agent)
 
 def run():
     main(sys.argv[1:])
